@@ -8,9 +8,7 @@
 #ifdef _OPENMP
 #include <omp.h>
 #endif //_OPENMP
-#if defined(__APPLE__)
-#include "vecLib/cblas.h"
-#elif defined(HAVE_FLEXIBLAS_CBLAS_H)
+#if defined(HAVE_FLEXIBLAS_CBLAS_H)
 #include "flexiblas/cblas.h"
 #elif defined(HAVE_OPENBLAS_CBLAS_H)
 #include "openblas/cblas.h"
